


*this file creates an output file so that I can run the regressions in SAS
*it uses as an input the file crim_oct.dta, a stata data set
*this file is incredibly bulky because I make 7 copies of the data so that I can stack the observations for the different crime categories
**that means I have to do each command 7 times 


drop _all

set more 1

set mat 400

set maxvar 2000 width 4000 maxobs 21500


use crime.dta

drop if city==.

*****I need to expand the dataset to stack the data

expand 7
sort city year
generate number=1
replace number=number[_n-1]+1 if city==city[_n-1]&year==year[_n-1]

tab number

**first I need to generate the variables, i.e. make per capita, percent changes, construct the stacked dependent variable, etc

sort number city year


replace sworn=sworn/citypop*100000
replace civil=civil/citypop*100000
replace murder=murder/citypop*100000
replace rape=rape/citypop*100000
replace robb=robb/citypop*100000
replace assa=assa/citypop*100000
replace burg=burg/citypop*100000
replace larc=larc/citypop*100000
replace auto=auto/citypop*100000
replace sta_wel=sta_wel/citypop*100000
replace sta_edu=sta_edu/citypop*100000


generate crime=0
replace  crime=murd if number==1
replace  crime=rape if number==2
replace  crime=robb if number==3
replace  crime=assa if number==4
replace crime=burg if number==5
replace crime=larc if number==6
replace crime=auto if number==7




gen d_sworn=ln(sworn)-ln(sworn[_n-1]) if city==city[_n-1]
gen d_civil=ln(civil)-ln(civil[_n-1]) if city==city[_n-1]


gen d_swo_1=d_sworn[_n-1] if year>69& (city==city[_n-2])
gen d_civ_1=d_civil[_n-1] if year>69& (city==city[_n-2])


gen d_swo_2=d_sworn[_n-2] if year>69& (city==city[_n-3])
gen d_civ_2=d_civil[_n-2] if year>69& (city==city[_n-3])



gen l_sworn=ln(sworn)
gen l_swo_1=l_sworn[_n-1] if (city==city[_n-1])
gen l_swo_2=l_sworn[_n-2] if (city==city[_n-2])



gen l_civil=ln(civil)
gen l_civ_1=l_civil[_n-1] if (city==city[_n-1])
gen l_civ_2=l_civil[_n-2] if (city==city[_n-2])


sort number city year

**now create the differenced logged crime rates


gen d_murder=ln(murder)-ln(murder[_n-1]) if city==city[_n-1]
gen d_rape=ln(rape)-ln(rape[_n-1]) if city==city[_n-1]
gen d_robber=ln(robber)-ln(robb[_n-1]) if city==city[_n-1]
gen d_burgla=ln(burgla)-ln(burg[_n-1]) if city==city[_n-1]
gen d_assaul=ln(assaul)-ln(assa[_n-1]) if city==city[_n-1]
gen d_larcen=ln(larcen)-ln(larc[_n-1]) if city==city[_n-1]
gen d_auto=ln(auto)-ln(auto[_n-1]) if city==city[_n-1]


gen l_murd=ln(murder)
gen l_rape=ln(rape)
gen l_robb=ln(robb)
gen l_assa=ln(assa)
gen l_burg=ln(burg)
gen l_larc=ln(larc)
gen l_auto=ln(auto)


sort number city year


***now create the election year dummies, only elecyear in there now
** elec_1 means election occured last year

generate elec_1=0
generate elec_2=0
generate elec_3=0

replace elec_1=1 if elecyear[_n-1]==1&city==city[_n-1]
replace elec_1=1 if elecyear[_n+3]==1&elecyear[_n+7]==1&city==city[_n+7]
replace elec_1=1 if elecyear[_n+1]==1&elecyear[_n+3]==1&city==city[_n+3]
replace elec_1=1 if elecyear[_n+2]==1&elecyear[_n+5]==1&city==city[_n+5]

replace elec_2=1 if elecyear[_n-2]==1&city==city[_n-2]
replace elec_2=1 if elecyear[_n+2]==1&elecyear[_n+6]==1&city==city[_n+6]
replace elec_2=1 if elecyear[_n+1]==1&elecyear[_n+4]==1&city==city[_n+4]

replace elec_3=1 if elecyear[_n-3]==1&city==city[_n-3]
replace elec_3=1 if elecyear[_n+1]==1&elecyear[_n+5]==1&city==city[_n+5]
replace elec_3=1 if elecyear[_n+3]==1&city==city[_n+3]&term3==1

**note that elec_3 is defined for cities with two year terms, won't be a
** problem because take care of it with interactions directly below


generate el_1t2=elec_1*term2
generate el_1t4=elec_1*(1-term2)
generate el_2t2=elec_2*term2
generate el_2t4=elec_2*(1-term2)
generate elecxt2=elecyear*term2
generate elecxt4=elecyear*(1-term2)

**that should be the mayoral elections



**now want gubernatorial elections
gen gov_1=0
gen gov_2=0
gen gov_3=0

replace gov_1=governor[_n-1] if city==city[_n-1]
*replace gov_1=gov_1[_n+4] if city==city[_n+4] 

replace gov_2=governor[_n-2] if city==city[_n-2]
*replace gov_2=gov_2[_n+4] if city==city[_n+4]

replace gov_3=governor[_n-3] if city==city[_n-3]&year>72
*replace gov_3=gov_3[_n+4] if city==city[_n+4]


summ gov*


***now lets generate the differenced demog variables
**and also just put x_ in front of non-differenced demog variables to make it simpler to include them in the regression command

gen c_unemp=unemp-unemp[_n-1]
gen x_unemp=unemp


gen a15_24=a15_19+a20_24
gen c_a15_24=a15_24-a15_24[_n-1]
gen x_a15_24=a15_24



gen c_black=citybla-citybla[_n-1]
gen c_femhea=cityfemh-cityfem[_n-1]

gen c_st_edu=ln(sta_edu)-ln(sta_edu[_n-1])
gen c_st_wel=ln(sta_wel)-ln(sta_wel[_n-1])

gen x_black=citybla
gen x_femhea=cityfem
gen x_st_edu=ln(sta_edu)
gen x_st_wel=ln(sta_wel)


***now need year dummies interacted with number, i.e. crime-specific year dummies

gen hold2=year
replace hold2=0 if number!=1
tab hold2, gen(yy3) nof
drop hold2

gen hold2=year
replace hold2=0 if number!=2
tab hold2, gen(yy4) nof
drop hold2

gen hold2=year
replace hold2=0 if number!=3
tab hold2, gen(yy5) nof
drop hold2

gen hold2=year
replace hold2=0 if number!=4
tab hold2, gen(yy6) nof
drop hold2



gen hold2=year
replace hold2=0 if number!=5
tab hold2, gen(yy7) nof
drop hold2

gen hold2=year
replace hold2=0 if number!=6
tab hold2, gen(yy8) nof
drop hold2

gen hold2=year
replace hold2=0 if number!=7
tab hold2, gen(yy9) nof
drop hold2


**now city dummies

tab city, gen(cc) nof

**these are not crime specific



**don't have data for before 70; just use it for constructing lags so drop it before running regressions

drop if year<70

**now generate city size dummies

generate citysize=0
replace citysize=1 if citypop<250000
replace citysize=2 if (citypop<500000&citypop>=250000)
replace citysize=3 if (citypop<1000000&citypop>=500000)
replace citysize=4 if (citypop>=1000000)

**now interact these with number

generate cs1=0
generate cs2=0
generate cs3=0
generate cs4=0
generate cs5=0
generate cs6=0
generate cs7=0
generate cs8=0
generate cs9=0
generate cs10=0
generate cs11=0
generate cs12=0
generate cs13=0
generate cs14=0
generate cs15=0
generate cs16=0
generate cs17=0
generate cs18=0
generate cs19=0
generate cs20=0
generate cs21=0
generate cs22=0
generate cs23=0
generate cs24=0
generate cs25=0
generate cs26=0
generate cs27=0
generate cs28=0


replace cs1=1 if citysize==1&number==1
replace cs2=1 if citysize==2&number==1
replace cs3=1 if citysize==3&number==1
replace cs4=1 if citysize==4&number==1

replace cs5=1 if citysize==1&number==2
replace cs6=1 if citysize==2&number==2
replace cs7=1 if citysize==3&number==2
replace cs8=1 if citysize==4&number==2

replace cs9=1 if citysize==1&number==3
replace cs10=1 if citysize==2&number==3
replace cs11=1 if citysize==3&number==3
replace cs12=1 if citysize==4&number==3

replace cs13=1 if citysize==1&number==4
replace cs14=1 if citysize==2&number==4
replace cs15=1 if citysize==3&number==4
replace cs16=1 if citysize==4&number==4

replace cs17=1 if citysize==1&number==5
replace cs18=1 if citysize==2&number==5
replace cs19=1 if citysize==3&number==5
replace cs20=1 if citysize==4&number==5

replace cs21=1 if citysize==1&number==6
replace cs22=1 if citysize==2&number==6
replace cs23=1 if citysize==3&number==6
replace cs24=1 if citysize==4&number==6

replace cs25=1 if citysize==1&number==7
replace cs26=1 if citysize==2&number==7
replace cs27=1 if citysize==3&number==7
replace cs28=1 if citysize==4&number==7



**now I need the  citysize instruments
** because of the stagger in the data with the police data being a snapshot as of the November, what I call year t police data in the paper is really year t-1 as my data set is constructed; i.e. want to look at effect of police as of this November on crime the following year to minimize simultaneity 


generate icsm1_1=cs1*elec_1
generate icsm2_1=cs2*elec_1
generate icsm3_1=cs3*elec_1
generate icsm4_1=cs4*elec_1
generate icsm5_1=cs5*elec_1
generate icsm6_1=cs6*elec_1
generate icsm7_1=cs7*elec_1
generate icsm8_1=cs8*elec_1
generate icsm9_1=cs9*elec_1
generate icsm10_1=cs10*elec_1
generate icsm11_1=cs11*elec_1
generate icsm12_1=cs12*elec_1
generate icsm13_1=cs13*elec_1
generate icsm14_1=cs14*elec_1
generate icsm15_1=cs15*elec_1
generate icsm16_1=cs16*elec_1
generate icsm17_1=cs17*elec_1
generate icsm18_1=cs18*elec_1
generate icsm19_1=cs19*elec_1
generate icsm20_1=cs20*elec_1
generate icsm21_1=cs21*elec_1
generate icsm22_1=cs22*elec_1
generate icsm23_1=cs23*elec_1
generate icsm24_1=cs24*elec_1
generate icsm25_1=cs25*elec_1
generate icsm26_1=cs26*elec_1
generate icsm27_1=cs27*elec_1
generate icsm28_1=cs28*elec_1


generate icsm1_2=cs1*elec_2
generate icsm2_2=cs2*elec_2
generate icsm3_2=cs3*elec_2
generate icsm4_2=cs4*elec_2
generate icsm5_2=cs5*elec_2
generate icsm6_2=cs6*elec_2
generate icsm7_2=cs7*elec_2
generate icsm8_2=cs8*elec_2
generate icsm9_2=cs9*elec_2
generate icsm10_2=cs10*elec_2
generate icsm11_2=cs11*elec_2
generate icsm12_2=cs12*elec_2
generate icsm13_2=cs13*elec_2
generate icsm14_2=cs14*elec_2
generate icsm15_2=cs15*elec_2
generate icsm16_2=cs16*elec_2
generate icsm17_2=cs17*elec_2
generate icsm18_2=cs18*elec_2
generate icsm19_2=cs19*elec_2
generate icsm20_2=cs20*elec_2
generate icsm21_2=cs21*elec_2
generate icsm22_2=cs22*elec_2
generate icsm23_2=cs23*elec_2
generate icsm24_2=cs24*elec_2
generate icsm25_2=cs25*elec_2
generate icsm26_2=cs26*elec_2
generate icsm27_2=cs27*elec_2
generate icsm28_2=cs28*elec_2




generate icsg1_1=cs1*gov_1
generate icsg2_1=cs2*gov_1
generate icsg3_1=cs3*gov_1
generate icsg4_1=cs4*gov_1
generate icsg5_1=cs5*gov_1
generate icsg6_1=cs6*gov_1
generate icsg7_1=cs7*gov_1
generate icsg8_1=cs8*gov_1
generate icsg9_1=cs9*gov_1
generate icsg10_1=cs10*gov_1
generate icsg11_1=cs11*gov_1
generate icsg12_1=cs12*gov_1
generate icsg13_1=cs13*gov_1
generate icsg14_1=cs14*gov_1
generate icsg15_1=cs15*gov_1
generate icsg16_1=cs16*gov_1
generate icsg17_1=cs17*gov_1
generate icsg18_1=cs18*gov_1
generate icsg19_1=cs19*gov_1
generate icsg20_1=cs20*gov_1
generate icsg21_1=cs21*gov_1
generate icsg22_1=cs22*gov_1
generate icsg23_1=cs23*gov_1
generate icsg24_1=cs24*gov_1
generate icsg25_1=cs25*gov_1
generate icsg26_1=cs26*gov_1
generate icsg27_1=cs27*gov_1
generate icsg28_1=cs28*gov_1


generate icsg1_2=cs1*gov_2
generate icsg2_2=cs2*gov_2
generate icsg3_2=cs3*gov_2
generate icsg4_2=cs4*gov_2
generate icsg5_2=cs5*gov_2
generate icsg6_2=cs6*gov_2
generate icsg7_2=cs7*gov_2
generate icsg8_2=cs8*gov_2
generate icsg9_2=cs9*gov_2
generate icsg10_2=cs10*gov_2
generate icsg11_2=cs11*gov_2
generate icsg12_2=cs12*gov_2
generate icsg13_2=cs13*gov_2
generate icsg14_2=cs14*gov_2
generate icsg15_2=cs15*gov_2
generate icsg16_2=cs16*gov_2
generate icsg17_2=cs17*gov_2
generate icsg18_2=cs18*gov_2
generate icsg19_2=cs19*gov_2
generate icsg20_2=cs20*gov_2
generate icsg21_2=cs21*gov_2
generate icsg22_2=cs22*gov_2
generate icsg23_2=cs23*gov_2
generate icsg24_2=cs24*gov_2
generate icsg25_2=cs25*gov_2
generate icsg26_2=cs26*gov_2
generate icsg27_2=cs27*gov_2
generate icsg28_2=cs28*gov_2



**now region dummies

egen holdr=max(censdist), by (city)
drop censdist
rename holdr censdist

generate region=0
replace region=1 if censdist<20&censdist!=.
replace region=2 if (censdist<30&censdist>=20)
replace region=3 if (censdist<40&censdist>=30)
replace region=4 if (censdist<50&censdist>=40)
replace region=5 if (censdist<60&censdist>=50)|city==50
replace region=6 if (censdist<70&censdist>=60)
replace region=7 if (censdist<80&censdist>=70)
replace region=8 if (censdist<90&censdist>=80)
replace region=9 if (censdist>=90)&censdist!=.

generate hold3=region+(9*(number-1))

tab hold3, gen(rr) nof




tab region

compress


**now I need the region instruments

generate irrm1_1=rr1*elec_1
generate irrm2_1=rr2*elec_1
generate irrm3_1=rr3*elec_1
generate irrm4_1=rr4*elec_1
generate irrm5_1=rr5*elec_1
generate irrm6_1=rr6*elec_1
generate irrm7_1=rr7*elec_1
generate irrm8_1=rr8*elec_1
generate irrm9_1=rr9*elec_1
generate irrm10_1=rr10*elec_1
generate irrm11_1=rr11*elec_1
generate irrm12_1=rr12*elec_1
generate irrm13_1=rr13*elec_1
generate irrm14_1=rr14*elec_1
generate irrm15_1=rr15*elec_1
generate irrm16_1=rr16*elec_1
generate irrm17_1=rr17*elec_1
generate irrm18_1=rr18*elec_1
generate irrm19_1=rr19*elec_1
generate irrm20_1=rr20*elec_1
generate irrm21_1=rr21*elec_1
generate irrm22_1=rr22*elec_1
generate irrm23_1=rr23*elec_1
generate irrm24_1=rr24*elec_1
generate irrm25_1=rr25*elec_1
generate irrm26_1=rr26*elec_1
generate irrm27_1=rr27*elec_1
generate irrm28_1=rr28*elec_1
generate irrm29_1=rr29*elec_1
generate irrm30_1=rr30*elec_1
generate irrm31_1=rr31*elec_1
generate irrm32_1=rr32*elec_1
generate irrm33_1=rr33*elec_1
generate irrm34_1=rr34*elec_1
generate irrm35_1=rr35*elec_1
generate irrm36_1=rr36*elec_1
generate irrm37_1=rr37*elec_1
generate irrm38_1=rr38*elec_1
generate irrm39_1=rr39*elec_1
generate irrm40_1=rr40*elec_1
generate irrm41_1=rr41*elec_1
generate irrm42_1=rr42*elec_1
generate irrm43_1=rr43*elec_1
generate irrm44_1=rr44*elec_1
generate irrm45_1=rr45*elec_1
generate irrm46_1=rr46*elec_1
generate irrm47_1=rr47*elec_1
generate irrm48_1=rr48*elec_1
generate irrm49_1=rr49*elec_1
generate irrm50_1=rr50*elec_1
generate irrm51_1=rr51*elec_1
generate irrm52_1=rr52*elec_1
generate irrm53_1=rr53*elec_1
generate irrm54_1=rr54*elec_1
generate irrm55_1=rr55*elec_1
generate irrm56_1=rr56*elec_1
generate irrm57_1=rr57*elec_1
generate irrm58_1=rr58*elec_1
generate irrm59_1=rr59*elec_1
generate irrm60_1=rr60*elec_1
generate irrm61_1=rr61*elec_1
generate irrm62_1=rr62*elec_1
generate irrm63_1=rr63*elec_1

















generate irrm1_2=rr1*elec_2
generate irrm2_2=rr2*elec_2
generate irrm3_2=rr3*elec_2
generate irrm4_2=rr4*elec_2
generate irrm5_2=rr5*elec_2
generate irrm6_2=rr6*elec_2
generate irrm7_2=rr7*elec_2
generate irrm8_2=rr8*elec_2
generate irrm9_2=rr9*elec_2
generate irrm10_2=rr10*elec_2
generate irrm11_2=rr11*elec_2
generate irrm12_2=rr12*elec_2
generate irrm13_2=rr13*elec_2
generate irrm14_2=rr14*elec_2
generate irrm15_2=rr15*elec_2
generate irrm16_2=rr16*elec_2
generate irrm17_2=rr17*elec_2
generate irrm18_2=rr18*elec_2
generate irrm19_2=rr19*elec_2
generate irrm20_2=rr20*elec_2
generate irrm21_2=rr21*elec_2
generate irrm22_2=rr22*elec_2
generate irrm23_2=rr23*elec_2
generate irrm24_2=rr24*elec_2
generate irrm25_2=rr25*elec_2
generate irrm26_2=rr26*elec_2
generate irrm27_2=rr27*elec_2
generate irrm28_2=rr28*elec_2
generate irrm29_2=rr29*elec_2
generate irrm30_2=rr30*elec_2
generate irrm31_2=rr31*elec_2
generate irrm32_2=rr32*elec_2
generate irrm33_2=rr33*elec_2
generate irrm34_2=rr34*elec_2
generate irrm35_2=rr35*elec_2
generate irrm36_2=rr36*elec_2
generate irrm37_2=rr37*elec_2
generate irrm38_2=rr38*elec_2
generate irrm39_2=rr39*elec_2
generate irrm40_2=rr40*elec_2
generate irrm41_2=rr41*elec_2
generate irrm42_2=rr42*elec_2
generate irrm43_2=rr43*elec_2
generate irrm44_2=rr44*elec_2
generate irrm45_2=rr45*elec_2
generate irrm46_2=rr46*elec_2
generate irrm47_2=rr47*elec_2
generate irrm48_2=rr48*elec_2
generate irrm49_2=rr49*elec_2
generate irrm50_2=rr50*elec_2
generate irrm51_2=rr51*elec_2
generate irrm52_2=rr52*elec_2
generate irrm53_2=rr53*elec_2
generate irrm54_2=rr54*elec_2
generate irrm55_2=rr55*elec_2
generate irrm56_2=rr56*elec_2
generate irrm57_2=rr57*elec_2
generate irrm58_2=rr58*elec_2
generate irrm59_2=rr59*elec_2
generate irrm60_2=rr60*elec_2
generate irrm61_2=rr61*elec_2
generate irrm62_2=rr62*elec_2
generate irrm63_2=rr63*elec_2



generate irrg1_1=rr1*gov_1
generate irrg2_1=rr2*gov_1
generate irrg3_1=rr3*gov_1
generate irrg4_1=rr4*gov_1
generate irrg5_1=rr5*gov_1
generate irrg6_1=rr6*gov_1
generate irrg7_1=rr7*gov_1
generate irrg8_1=rr8*gov_1
generate irrg9_1=rr9*gov_1
generate irrg10_1=rr10*gov_1
generate irrg11_1=rr11*gov_1
generate irrg12_1=rr12*gov_1
generate irrg13_1=rr13*gov_1
generate irrg14_1=rr14*gov_1
generate irrg15_1=rr15*gov_1
generate irrg16_1=rr16*gov_1
generate irrg17_1=rr17*gov_1
generate irrg18_1=rr18*gov_1
generate irrg19_1=rr19*gov_1
generate irrg20_1=rr20*gov_1
generate irrg21_1=rr21*gov_1
generate irrg22_1=rr22*gov_1
generate irrg23_1=rr23*gov_1
generate irrg24_1=rr24*gov_1
generate irrg25_1=rr25*gov_1
generate irrg26_1=rr26*gov_1
generate irrg27_1=rr27*gov_1
generate irrg28_1=rr28*gov_1
generate irrg29_1=rr29*gov_1
generate irrg30_1=rr30*gov_1
generate irrg31_1=rr31*gov_1
generate irrg32_1=rr32*gov_1
generate irrg33_1=rr33*gov_1
generate irrg34_1=rr34*gov_1
generate irrg35_1=rr35*gov_1
generate irrg36_1=rr36*gov_1
generate irrg37_1=rr37*gov_1
generate irrg38_1=rr38*gov_1
generate irrg39_1=rr39*gov_1
generate irrg40_1=rr40*gov_1
generate irrg41_1=rr41*gov_1
generate irrg42_1=rr42*gov_1
generate irrg43_1=rr43*gov_1
generate irrg44_1=rr44*gov_1
generate irrg45_1=rr45*gov_1
generate irrg46_1=rr46*gov_1
generate irrg47_1=rr47*gov_1
generate irrg48_1=rr48*gov_1
generate irrg49_1=rr49*gov_1
generate irrg50_1=rr50*gov_1
generate irrg51_1=rr51*gov_1
generate irrg52_1=rr52*gov_1
generate irrg53_1=rr53*gov_1
generate irrg54_1=rr54*gov_1
generate irrg55_1=rr55*gov_1
generate irrg56_1=rr56*gov_1
generate irrg57_1=rr57*gov_1
generate irrg58_1=rr58*gov_1
generate irrg59_1=rr59*gov_1
generate irrg60_1=rr60*gov_1
generate irrg61_1=rr61*gov_1
generate irrg62_1=rr62*gov_1
generate irrg63_1=rr63*gov_1

generate irrg1_2=rr1*gov_2
generate irrg2_2=rr2*gov_2
generate irrg3_2=rr3*gov_2
generate irrg4_2=rr4*gov_2
generate irrg5_2=rr5*gov_2
generate irrg6_2=rr6*gov_2
generate irrg7_2=rr7*gov_2
generate irrg8_2=rr8*gov_2
generate irrg9_2=rr9*gov_2
generate irrg10_2=rr10*gov_2
generate irrg11_2=rr11*gov_2
generate irrg12_2=rr12*gov_2
generate irrg13_2=rr13*gov_2
generate irrg14_2=rr14*gov_2
generate irrg15_2=rr15*gov_2
generate irrg16_2=rr16*gov_2
generate irrg17_2=rr17*gov_2
generate irrg18_2=rr18*gov_2
generate irrg19_2=rr19*gov_2
generate irrg20_2=rr20*gov_2
generate irrg21_2=rr21*gov_2
generate irrg22_2=rr22*gov_2
generate irrg23_2=rr23*gov_2
generate irrg24_2=rr24*gov_2
generate irrg25_2=rr25*gov_2
generate irrg26_2=rr26*gov_2
generate irrg27_2=rr27*gov_2
generate irrg28_2=rr28*gov_2
generate irrg29_2=rr29*gov_2
generate irrg30_2=rr30*gov_2
generate irrg31_2=rr31*gov_2
generate irrg32_2=rr32*gov_2
generate irrg33_2=rr33*gov_2
generate irrg34_2=rr34*gov_2
generate irrg35_2=rr35*gov_2
generate irrg36_2=rr36*gov_2
generate irrg37_2=rr37*gov_2
generate irrg38_2=rr38*gov_2
generate irrg39_2=rr39*gov_2
generate irrg40_2=rr40*gov_2
generate irrg41_2=rr41*gov_2
generate irrg42_2=rr42*gov_2
generate irrg43_2=rr43*gov_2
generate irrg44_2=rr44*gov_2
generate irrg45_2=rr45*gov_2
generate irrg46_2=rr46*gov_2
generate irrg47_2=rr47*gov_2
generate irrg48_2=rr48*gov_2
generate irrg49_2=rr49*gov_2
generate irrg50_2=rr50*gov_2
generate irrg51_2=rr51*gov_2
generate irrg52_2=rr52*gov_2
generate irrg53_2=rr53*gov_2
generate irrg54_2=rr54*gov_2
generate irrg55_2=rr55*gov_2
generate irrg56_2=rr56*gov_2
generate irrg57_2=rr57*gov_2
generate irrg58_2=rr58*gov_2
generate irrg59_2=rr59*gov_2
generate irrg60_2=rr60*gov_2
generate irrg61_2=rr61*gov_2
generate irrg62_2=rr62*gov_2
generate irrg63_2=rr63*gov_2

compress



sort number city year


*last thing to do is to interact election variables, police variables and demog controls with number 

**first election variables


generate im1_el1=0
generate im2_el1=0
generate im3_el1=0
generate im4_el1=0
generate im5_el1=0
generate im6_el1=0
generate im7_el1=0

replace im1_el1=1 if elec_1==1&number==1
replace im2_el1=1 if elec_1==1&number==2
replace im3_el1=1 if elec_1==1&number==3
replace im4_el1=1 if elec_1==1&number==4
replace im5_el1=1 if elec_1==1&number==5
replace im6_el1=1 if elec_1==1&number==6
replace im7_el1=1 if elec_1==1&number==7

generate im1_el2=0
generate im2_el2=0
generate im3_el2=0
generate im4_el2=0
generate im5_el2=0
generate im6_el2=0
generate im7_el2=0

replace im1_el2=1 if elec_2==1&number==1
replace im2_el2=1 if elec_2==1&number==2
replace im3_el2=1 if elec_2==1&number==3
replace im4_el2=1 if elec_2==1&number==4
replace im5_el2=1 if elec_2==1&number==5
replace im6_el2=1 if elec_2==1&number==6
replace im7_el2=1 if elec_2==1&number==7


**now governor's races

generate ig1_el1=0
generate ig2_el1=0
generate ig3_el1=0
generate ig4_el1=0
generate ig5_el1=0
generate ig6_el1=0
generate ig7_el1=0

replace ig1_el1=1 if gov_1==1&number==1
replace ig2_el1=1 if gov_1==1&number==2
replace ig3_el1=1 if gov_1==1&number==3
replace ig4_el1=1 if gov_1==1&number==4
replace ig5_el1=1 if gov_1==1&number==5
replace ig6_el1=1 if gov_1==1&number==6
replace ig7_el1=1 if gov_1==1&number==7

generate ig1_el2=0
generate ig2_el2=0
generate ig3_el2=0
generate ig4_el2=0
generate ig5_el2=0
generate ig6_el2=0
generate ig7_el2=0

replace ig1_el2=1 if gov_2==1&number==1
replace ig2_el2=1 if gov_2==1&number==2
replace ig3_el2=1 if gov_2==1&number==3
replace ig4_el2=1 if gov_2==1&number==4
replace ig5_el2=1 if gov_2==1&number==5
replace ig6_el2=1 if gov_2==1&number==6
replace ig7_el2=1 if gov_2==1&number==7


**now the demographic variables in levels

gen xx1_fem=x_femhea
gen xx2_fem=x_femhea
gen xx3_fem=x_femhea
gen xx4_fem=x_femhea
gen xx5_fem=x_femhea
gen xx6_fem=x_femhea
gen xx7_fem=x_femhea

replace xx1_fem=0 if number!=1
replace xx2_fem=0 if number!=2
replace xx3_fem=0 if number!=3
replace xx4_fem=0 if number!=4
replace xx5_fem=0 if number!=5
replace xx6_fem=0 if number!=6
replace xx7_fem=0 if number!=7


gen xx1_bla=x_black
gen xx2_bla=x_black
gen xx3_bla=x_black
gen xx4_bla=x_black
gen xx5_bla=x_black
gen xx6_bla=x_black
gen xx7_bla=x_black

replace xx1_bla=0 if number!=1
replace xx2_bla=0 if number!=2
replace xx3_bla=0 if number!=3
replace xx4_bla=0 if number!=4
replace xx5_bla=0 if number!=5
replace xx6_bla=0 if number!=6
replace xx7_bla=0 if number!=7


gen xx1_wel=x_st_wel
gen xx2_wel=x_st_wel
gen xx3_wel=x_st_wel
gen xx4_wel=x_st_wel
gen xx5_wel=x_st_wel
gen xx6_wel=x_st_wel
gen xx7_wel=x_st_wel

replace xx1_wel=0 if number!=1
replace xx2_wel=0 if number!=2
replace xx3_wel=0 if number!=3
replace xx4_wel=0 if number!=4
replace xx5_wel=0 if number!=5
replace xx6_wel=0 if number!=6
replace xx7_wel=0 if number!=7


gen xx1_edu=x_st_edu
gen xx2_edu=x_st_edu
gen xx3_edu=x_st_edu
gen xx4_edu=x_st_edu
gen xx5_edu=x_st_edu
gen xx6_edu=x_st_edu
gen xx7_edu=x_st_edu

replace xx1_edu=0 if number!=1
replace xx2_edu=0 if number!=2
replace xx3_edu=0 if number!=3
replace xx4_edu=0 if number!=4
replace xx5_edu=0 if number!=5
replace xx6_edu=0 if number!=6
replace xx7_edu=0 if number!=7


gen xx1_une=unemp
gen xx2_une=unemp
gen xx3_une=unemp
gen xx4_une=unemp
gen xx5_une=unemp
gen xx6_une=unemp
gen xx7_une=unemp

replace xx1_une=0 if number!=1
replace xx2_une=0 if number!=2
replace xx3_une=0 if number!=3
replace xx4_une=0 if number!=4
replace xx5_une=0 if number!=5
replace xx6_une=0 if number!=6
replace xx7_une=0 if number!=7

gen xx1_age=x_a15_24
gen xx2_age=x_a15_24
gen xx3_age=x_a15_24
gen xx4_age=x_a15_24
gen xx5_age=x_a15_24
gen xx6_age=x_a15_24
gen xx7_age=x_a15_24

replace xx1_age=0 if number!=1
replace xx2_age=0 if number!=2
replace xx3_age=0 if number!=3
replace xx4_age=0 if number!=4
replace xx5_age=0 if number!=5
replace xx6_age=0 if number!=6
replace xx7_age=0 if number!=7


************now the demog variables in changes

gen dd1_fem=c_fem
gen dd2_fem=c_fem
gen dd3_fem=c_fem
gen dd4_fem=c_fem
gen dd5_fem=c_fem
gen dd6_fem=c_fem
gen dd7_fem=c_fem

replace dd1_fem=0 if number!=1
replace dd2_fem=0 if number!=2
replace dd3_fem=0 if number!=3
replace dd4_fem=0 if number!=4
replace dd5_fem=0 if number!=5
replace dd6_fem=0 if number!=6
replace dd7_fem=0 if number!=7


gen dd1_bla=c_black
gen dd2_bla=c_black
gen dd3_bla=c_black
gen dd4_bla=c_black
gen dd5_bla=c_black
gen dd6_bla=c_black
gen dd7_bla=c_black

replace dd1_bla=0 if number!=1
replace dd2_bla=0 if number!=2
replace dd3_bla=0 if number!=3
replace dd4_bla=0 if number!=4
replace dd5_bla=0 if number!=5
replace dd6_bla=0 if number!=6
replace dd7_bla=0 if number!=7


gen dd1_wel=c_st_wel
gen dd2_wel=c_st_wel
gen dd3_wel=c_st_wel
gen dd4_wel=c_st_wel
gen dd5_wel=c_st_wel
gen dd6_wel=c_st_wel
gen dd7_wel=c_st_wel

replace dd1_wel=0 if number!=1
replace dd2_wel=0 if number!=2
replace dd3_wel=0 if number!=3
replace dd4_wel=0 if number!=4
replace dd5_wel=0 if number!=5
replace dd6_wel=0 if number!=6
replace dd7_wel=0 if number!=7


gen dd1_edu=c_st_edu
gen dd2_edu=c_st_edu
gen dd3_edu=c_st_edu
gen dd4_edu=c_st_edu
gen dd5_edu=c_st_edu
gen dd6_edu=c_st_edu
gen dd7_edu=c_st_edu

replace dd1_edu=0 if number!=1
replace dd2_edu=0 if number!=2
replace dd3_edu=0 if number!=3
replace dd4_edu=0 if number!=4
replace dd5_edu=0 if number!=5
replace dd6_edu=0 if number!=6
replace dd7_edu=0 if number!=7


gen dd1_une=c_unemp
gen dd2_une=c_unemp
gen dd3_une=c_unemp
gen dd4_une=c_unemp
gen dd5_une=c_unemp
gen dd6_une=c_unemp
gen dd7_une=c_unemp

replace dd1_une=0 if number!=1
replace dd2_une=0 if number!=2
replace dd3_une=0 if number!=3
replace dd4_une=0 if number!=4
replace dd5_une=0 if number!=5
replace dd6_une=0 if number!=6
replace dd7_une=0 if number!=7

gen dd1_age=c_a15_24
gen dd2_age=c_a15_24
gen dd3_age=c_a15_24
gen dd4_age=c_a15_24
gen dd5_age=c_a15_24
gen dd6_age=c_a15_24
gen dd7_age=c_a15_24

replace dd1_age=0 if number!=1
replace dd2_age=0 if number!=2
replace dd3_age=0 if number!=3
replace dd4_age=0 if number!=4
replace dd5_age=0 if number!=5
replace dd6_age=0 if number!=6
replace dd7_age=0 if number!=7



*******now sworn officers and total police interacted with number


gen dswo1_1=d_swo_1
gen dswo2_1=d_swo_1
gen dswo3_1=d_swo_1
gen dswo4_1=d_swo_1
gen dswo5_1=d_swo_1
gen dswo6_1=d_swo_1
gen dswo7_1=d_swo_1

replace dswo1_1=0 if number!=1
replace dswo2_1=0 if number!=2
replace dswo3_1=0 if number!=3
replace dswo4_1=0 if number!=4
replace dswo5_1=0 if number!=5
replace dswo6_1=0 if number!=6
replace dswo7_1=0 if number!=7


gen dswo1_2=d_swo_2
gen dswo2_2=d_swo_2
gen dswo3_2=d_swo_2
gen dswo4_2=d_swo_2
gen dswo5_2=d_swo_2
gen dswo6_2=d_swo_2
gen dswo7_2=d_swo_2

replace dswo1_2=0 if number!=1
replace dswo2_2=0 if number!=2
replace dswo3_2=0 if number!=3
replace dswo4_2=0 if number!=4
replace dswo5_2=0 if number!=5
replace dswo6_2=0 if number!=6
replace dswo7_2=0 if number!=7



**now in logs


gen lswo1_1=l_swo_1
gen lswo2_1=l_swo_1
gen lswo3_1=l_swo_1
gen lswo4_1=l_swo_1
gen lswo5_1=l_swo_1
gen lswo6_1=l_swo_1
gen lswo7_1=l_swo_1

replace lswo1_1=0 if number!=1
replace lswo2_1=0 if number!=2
replace lswo3_1=0 if number!=3
replace lswo4_1=0 if number!=4
replace lswo5_1=0 if number!=5
replace lswo6_1=0 if number!=6
replace lswo7_1=0 if number!=7


gen lswo1_2=l_swo_2
gen lswo2_2=l_swo_2
gen lswo3_2=l_swo_2
gen lswo4_2=l_swo_2
gen lswo5_2=l_swo_2
gen lswo6_2=l_swo_2
gen lswo7_2=l_swo_2

replace lswo1_2=0 if number!=1
replace lswo2_2=0 if number!=2
replace lswo3_2=0 if number!=3
replace lswo4_2=0 if number!=4
replace lswo5_2=0 if number!=5
replace lswo6_2=0 if number!=6
replace lswo7_2=0 if number!=7



*drop yy1 yy2 yy3




keep d_sworn d_swo_1 d_swo_2 l_swo_1 l_swo_2 l_crim d_crim l_murd l_rape l_robb l_assa l_burg l_larc l_auto d_murd d_rape d_robb d_assa d_burg d_larc d_auto yy* elec_1 gov_1 elec_2 gov_2 x_* c_*  rr* cs* dswo* lswo* dd* xx* ig* im* irr* ics* number citypop cc*



outfile using crim_sas.dat, replace

log using varlist.log, replace

desc


log close










