* this file gets data in shape and runs first stage regressions


drop _all

set more 1

set mat 400

set maxvar 1000 width 2000 maxobs 3000


use crime.dta



**first I need to create percent change in police vars

sort city year



replace sworn=sworn/citypop*100000
replace civil=civil/citypop*100000
replace murder=murder/citypop*100000
replace rape=rape/citypop*100000
replace robb=robb/citypop*100000
replace assa=assa/citypop*100000
replace burg=burg/citypop*100000
replace larc=larc/citypop*100000
replace auto=auto/citypop*100000




generate violent=murder+rape+robbery+assa
generate property=burgl+larc+auto




gen d_sworn=ln(sworn)-ln(sworn[_n-1]) if city==city[_n-1]
gen d_civil=ln(civil)-ln(civil[_n-1]) if city==city[_n-1]


gen d_swo_1=d_sworn[_n-1] if year>69& (city==city[_n-2])
gen d_civ_1=d_civil[_n-1] if year>69& (city==city[_n-2])


gen d_swo_2=d_sworn[_n-2] if year>69& (city==city[_n-3])
gen d_civ_2=d_civil[_n-2] if year>69& (city==city[_n-3])




gen l_sworn=ln(sworn)
gen l_swo_1=l_sworn[_n-1] if (city==city[_n-1])
gen l_swo_2=l_sworn[_n-2] if (city==city[_n-2])

gen l_civil=ln(civil)
gen l_civ_1=l_civil[_n-1] if (city==city[_n-1])
gen l_civ_2=l_civil[_n-2] if (city==city[_n-2])


sort city year

**now create the differenced logged crime rates


gen d_murder=ln(murder)-ln(murder[_n-1]) if city==city[_n-1]
gen d_rape=ln(rape)-ln(rape[_n-1]) if city==city[_n-1]
gen d_robber=ln(robber)-ln(robb[_n-1]) if city==city[_n-1]
gen d_burgla=ln(burgla)-ln(burg[_n-1]) if city==city[_n-1]
gen d_assaul=ln(assaul)-ln(assa[_n-1]) if city==city[_n-1]
gen d_larcen=ln(larcen)-ln(larc[_n-1]) if city==city[_n-1]
gen d_auto=ln(auto)-ln(auto[_n-1]) if city==city[_n-1]
gen d_viol=ln(viol)-ln(viol[_n-1]) if city==city[_n-1]
gen d_prop=ln(prop)-ln(prop[_n-1]) if city==city[_n-1]




gen l_murd=ln(murder)
gen l_rape=ln(rape)
gen l_robb=ln(robb)
gen l_assa=ln(assa)
gen l_burg=ln(burg)
gen l_larc=ln(larc)
gen l_auto=ln(auto)
gen l_viol=ln(viol)
gen l_prop=ln(prop)




sort city year


***now create the election year dummies, only elecyear in there now
**note that these are new definitions: elec_1 means election last year

generate elec_1=0
generate elec_2=0
generate elec_3=0

replace elec_1=1 if elecyear[_n-1]==1&city==city[_n-1]
replace elec_1=1 if elecyear[_n+3]==1&elecyear[_n+7]==1&city==city[_n+7]
replace elec_1=1 if elecyear[_n+1]==1&elecyear[_n+3]==1&city==city[_n+3]
replace elec_1=1 if elecyear[_n+2]==1&elecyear[_n+5]==1&city==city[_n+5]

replace elec_2=1 if elecyear[_n-2]==1&city==city[_n-2]
replace elec_2=1 if elecyear[_n+2]==1&elecyear[_n+6]==1&city==city[_n+6]
replace elec_2=1 if elecyear[_n+1]==1&elecyear[_n+4]==1&city==city[_n+4]

replace elec_3=1 if elecyear[_n-3]==1&city==city[_n-3]
replace elec_3=1 if elecyear[_n+1]==1&elecyear[_n+5]==1&city==city[_n+5]
replace elec_3=1 if elecyear[_n+3]==1&city==city[_n+3]&term3==1

**note that elec_3 is defined for cities with two year terms;
** not a problem because I never use elec_3 in regressions


generate el_1t2=elec_1*term2
generate el_1t4=elec_1*(1-term2)
generate el_2t4=elec_2*(1-term2)
generate el_3t4=elec_3*(1-term2)
generate elecxt2=elecyear*term2
generate elecxt4=elecyear*(1-term2)

**that should be the mayoral elections



**now want gubernatorial elections
gen gov_1=0
gen gov_2=0
gen gov_3=0

replace gov_1=governor[_n-1] if city==city[_n-1]


replace gov_2=governor[_n-2] if city==city[_n-2]


replace gov_3=governor[_n-3] if city==city[_n-3]&year>72




summ gov*






***now lets generate the logged demog variables

replace sta_edu=sta_edu/citypop*100000
replace sta_wel=sta_wel/citypop*100000

gen c_unemp=unemp-unemp[_n-1]
gen x_unemp=unemp


gen a15_24=a15_19+a20_24
gen c_a15_24=a15_24-a15_24[_n-1]
gen x_a15_24=a15_24



gen c_black=citybla-citybla[_n-1]
gen c_femhea=cityfemh-cityfem[_n-1]

gen c_st_edu=ln(sta_edu)-ln(sta_edu[_n-1])
gen c_st_wel=ln(sta_wel)-ln(sta_wel[_n-1])

gen x_black=citybla
gen x_femhea=cityfem
gen x_st_edu=ln(sta_edu)
gen x_st_wel=ln(sta_wel)


summ d_* c_* if year>70

***now need year dummies

tab year, gen(yy) nof

**now city dummies

tab city, gen(cc) nof




**now generate city size dummies

generate citysize=0
replace citysize=1 if citypop<250000
replace citysize=2 if (citypop<500000&citypop>=250000)
replace citysize=3 if (citypop<1000000&citypop>=500000)
replace citysize=5 if (citypop>=1000000)

tab citysize, gen(cs) nof

**now region dummies

egen holdr=max(censdist), by (city)
list city year if holdr==.
list city year if holdr<10
drop censdist
rename holdr censdist

generate region=0
replace region=1 if censdist<20&censdist!=.
replace region=2 if (censdist<30&censdist>=20)
replace region=3 if (censdist<40&censdist>=30)
replace region=4 if (censdist<50&censdist>=40)
replace region=5 if (censdist<60&censdist>=50)|city==50
replace region=6 if (censdist<70&censdist>=60)
replace region=7 if (censdist<80&censdist>=70)
replace region=8 if (censdist<90&censdist>=80)
replace region=9 if (censdist>=90)&censdist!=.



tab region




drop if year<70



log using firststa.log, replace


**this is the first stage of police, run on august 16, 1995


hreg d_sworn elecyear govern 
testparm elec* gov*

hreg d_sworn elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum



hreg d_sworn elecyear govern yy*
testparm elec* gov*

hreg d_sworn elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum


hreg d_sworn elecyear govern yy* c_* cs* 
testparm elec* gov*


hreg d_sworn elecyear govern yy* c_* cs* cc*
testparm elec* gov*

hreg d_sworn elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy* c_* cs* 
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum

hreg d_sworn elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy* c_* cs* cc*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum



*****now see what happens to other spending with elections


hreg c_st_edu elecyear govern 
testparm elec* gov*

hreg c_st_edu elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum



hreg c_st_edu elecyear govern yy*
testparm elec* gov*

hreg c_st_edu elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum


hreg c_st_edu elecyear govern yy* c_une c_bla c_a c_fem c_st_wel cs* cc*
testparm elec* gov*

hreg c_st_edu elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy* c_une c_bla c_a c_fem c_st_wel cs* cc*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum





hreg c_st_wel elecyear govern 
testparm elec* gov*

hreg c_st_wel elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum



hreg c_st_wel elecyear govern yy*
testparm elec* gov*

hreg c_st_wel elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum


hreg c_st_wel elecyear govern yy* c_une c_bla c_a c_fem c_st_edu  cs* cc*
testparm elec* gov*

hreg c_st_wel elecxt2 elecxt4 el_1t4 el_2t4 govern gov_1 gov_2 yy* c_une c_bla c_a c_fem c_st_edu  cs* cc*
testparm elecxt2 elecxt4
testparm elecxt2 elecxt4 govern
test el_1t4==0
test el_2t4==0, accum
test gov_1==0, accum
test gov_2==0, accum



log close










