/*Here I just want to see what the covariances between the individual
estimates are...

NOTE: This program is a duplicate of table1.sas, but has been altered
      slightly to spit out the vcov of the estimates.

%chkcov() uses:
  weight =holdwght or holdstd
  model  =1,2,3,4: (1,3)=7 elasticities, (2,4)=2 elasticities
          1: 2SLS/LIML, seven crime elasticities
          2: 2SLS/LIML, two crime elasticities (violent,property)
          3: OLS, differences, seven crime elasticities
          4: OLS, differences, two crime elasticities
  est    =2sls or liml (for models 1,2)
  iset   =z1-z28,z29-140, z141-z392
          z1-z28: elections uninteracted
          z29-z140: elections interacted with city-size dummies
          z141-z392: elections interacted with region dummies
*/

%macro chkcov(weight,model,est,iset);
%if &model=1 %then %do;
  %let wset=w1-w290 w333-w344;
  proc syslin data=use out=use &est;
    title "Model &model, &est results, unweighted";
    instruments &iset &wset;
    endogenous y x1_1-x1_7 x2_1-x2_7;
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    output R=yresid;
  proc means data=use noprint;
    by number;
    var yresid y;
    output out=stdpol(drop=_type_ _freq_) std(yresid)=holdstd std(y)=unc_std;
  proc print data=stdpol;
    title "(conditional) standard deviations of crime categories, Model &model, &est results";
  data _null_;
    set use;
    file "~/j2/website/programs/checkcov.raw";
    if _n_=1 then put "@number, first step 2SLS (unpooled) residuals@";
    put number 1.0 +2 yresid 18.12;
  data use(drop=yresid);
    merge use stdpol;
    by number;
    holdwght=1/(holdstd*holdstd);
  proc syslin data=use out=use &est outest=bcov covout;
    title "Model &model, &est results, weighted using &weight";
    instruments &iset &wset;
    endogenous y x1_1-x1_7 x2_1-x2_7;
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    weight &weight;
 /*test whether the crime estimates are zero*/
    %do i=1 %to 7; test x1_&i+x2_&i=0; %end;
 /*test whether the violent,property estimates are equal*/
    test x1_1 +x2_1 %do i=2 %to 4; 
        =x1_&i+x2_&i %end; ;
    test x1_5 +x2_5 %do i=6 %to 7;
        =x1_&i+x2_&i %end; ;
    test x1_1+x2_1=0 %do i=2 %to 7; ,x1_&i+x2_&i=0 %end; ;
    output R=yresid;
  proc print data=bcov;
  proc syslin data=use ols;
    title "Over-ID: chi-square with 14=28-14 dof";
    model yresid = &iset &wset;
    weight &weight;
%end;
%if &model=2 %then %do;
  %let wset=w1-w290 w333-w344;
  proc syslin data=use out=use &est;
    title "Model &model, &est results, unweighted";
    instruments &iset &wset;
    endogenous y x1_1-x1_7 x2_1-x2_7;
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    restrict x1_1+x2_1=x1_2+x2_2,
             x1_1+x2_1=x1_3+x2_3,
             x1_1+x2_1=x1_4+x2_4,

             x1_5+x2_5=x1_6+x2_6,
             x1_5+x2_5=x1_7+x2_7;
    output R=yresid;
  proc means data=use noprint;
    by number;
    var yresid y;
    output out=stdpol(drop=_type_ _freq_) std(yresid)=holdstd std(y)=unc_std;
  proc print data=stdpol;
    title "(conditional) standard deviations of crime categories";
  data use(drop=yresid);
    merge use stdpol;
    by number;
    holdwght=1/(holdstd*holdstd);
  proc syslin data=use out=use &est outest=bcov covout;
    title "Model &model, &est results, weighted using &weight";
    instruments &iset &wset;
    endogenous y x1_1-x1_7 x2_1-x2_7;
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    restrict x1_1+x2_1=x1_2+x2_2,
             x1_1+x2_1=x1_3+x2_3,
             x1_1+x2_1=x1_4+x2_4,

             x1_5+x2_5=x1_6+x2_6,
             x1_5+x2_5=x1_7+x2_7;
    weight &weight;
 /*test whether violent,property elasticities zero*/
    test x1_1+x2_1=0; /*violent crime*/
    test x1_5+x2_5=0; /*property crime*/
    test x1_1+x2_1=0,x1_5+x2_5=0;
    output R=yresid;
  proc print data=bcov;
  proc syslin data=use ols;
    title "Over-ID: chi-square with 14=28-14 dof";
    model yresid = &iset &wset;
    weight &weight;
%end;

%if &model=3 %then %do;
  %let wset=w1-w290 w333-w344;
  proc syslin data=use out=use ols;
    title "Model &model.(OLS,differences,7 elasticities), unweighted";
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    output R=yresid;
  proc means data=use noprint;
    by number;
    var yresid y;
    output out=stdpol(drop=_type_ _freq_) std(yresid)=holdstd std(y)=unc_std;
  proc print data=stdpol;
    title "standard deviations of the crime categories";
  data use(drop=yresid);
    merge use stdpol;
    by number;
    holdwght=1/(holdstd*holdstd);
  proc syslin data=use ols;
    title "Model &model.(OLS,differences,7 elasticities), weighted by &weight";
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    weight &weight;
 /*test whether the crime estimates are zero*/
    %do i=1 %to 7; test x1_&i+x2_&i=0; %end;
 /*test whether the violent,property estimates are equal*/
    test x1_1 +x2_1 %do i=2 %to 4; 
        =x1_&i+x2_&i %end; ;
    test x1_5 +x2_5 %do i=6 %to 7;
        =x1_&i+x2_&i %end; ;
    test x1_1+x2_1=0 %do i=2 %to 7; ,x1_&i+x2_&i=0 %end; ;
%end;
%if &model=4 %then %do;
  %let wset=w1-w290 w333-w344;
  proc syslin data=use out=use ols;
    title "Model &model.(OLS,differences,2elasticities), unweighted";
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    restrict x1_1+x2_1=x1_2+x2_2,
             x1_1+x2_1=x1_3+x2_3,
             x1_1+x2_1=x1_4+x2_4,

             x1_5+x2_5=x1_6+x2_6,
             x1_5+x2_5=x1_7+x2_7;
    output R=yresid;
  proc means data=use noprint;
    by number;
    var yresid y;
    output out=stdpol(drop=_type_ _freq_) std(yresid)=holdstd std(y)=unc_std;
  proc print data=stdpol;
    title "(conditional) standard deviations of crime categories";
  data use(drop=yresid);
    merge use stdpol;
    by number;
    holdwght=1/(holdstd*holdstd);
  proc syslin data=use ols;
    title "Model &model.(OLS,differences,2elasticities), weighted by &weight";
    model y=x1_1-x1_7 x2_1-x2_7 &wset;
    restrict x1_1+x2_1=x1_2+x2_2,
             x1_1+x2_1=x1_3+x2_3,
             x1_1+x2_1=x1_4+x2_4,

             x1_5+x2_5=x1_6+x2_6,
             x1_5+x2_5=x1_7+x2_7;
    weight &weight;
 /*test whether violent,property elasticities zero*/
    test x1_1+x2_1=0; /*violent crime*/
    test x1_5+x2_5=0; /*property crime*/
%end;

run;
%mend;











