options compress=yes macrogen nomprint nocenter;
libname sasdat '/tmp/justin';

x "\cp ~/j2/website/data/crime2.ssd01 /tmp/justin";

/************************************************
 NOTE: This file is designed to produce all results cited in my paper
       "Do Electoral Cycles in Police Hiring Really Help Us Estimate
       the Effect of Police on Crime?", Center for Labor Economics
       Working Paper # 35, available at
       http://elsa.berkeley.edu/replications/mccrary/clewp35.pdf.
 NOTE: All analysis in this file is based on crime2.ssd01.
 NOTE: I assume throughout that users know and understand macro
       language in SAS.  Otherwise the programming becomes truly
       cumbersome.  If you are confused about exactly what a macro of
       mine is doing, note that the log file will restate (in all
       caps) what the macro language "compiles" to, so that you can
       figure out what is going on. There are two options specified in
       the top line of the program "macrogen nomprint" which tell SAS
       to do this.

 Step 1. Normalize crime and police by population, difference the
         data, prepare covariates (lots of interactions and
         such), and save as work.crime2 to be used for Table 2 (the
         first stage).

 Step 2. Take work.crime2 and "stack" it up for Levitt's joint
         estimation of all seven crime categories simultaneously.
         This is is where it is very useful to know macro language. 

 Step 3. Run table1.sas, which produces all results in Table 1 of
         McCrary's paper.

 Step 4. Run table2.sas, which produces all results in Table 2 of
         McCrary's paper.

 NOTE: table1.sas will also produce all the estimates in Table A.1.
       See table1.sas.
 NOTE: Footnote 10 of CLEWP35 states that the correlation between
       the unpooled estimates is small (-0.04 to 0.02).  The macro
       chkcov will produce the variance covariance matrix of the
       estimates.  However, I have not taken the time to spit out only
       the relevant portion of the variance covariance matrix.  As
       such, this (much larger) output sequence is contained in the
       file master.lst.2.  The rest of the output for the paper is
       small in size, and is contained in master.lst.1.
 NOTE: Both the pooled AND the unpooled estimates make constraints 
       across the crime categories, which is why it is necessary (or
       at least convenient) to "stack" the data in Step 2.

**************************************************/

%include "~/j2/website/programs/step1.sas"; %step1;
   /*Step 1 creates work.crime2*/
%include "~/j2/website/programs/step2.sas";
   /*Step 2 stacks work.crime2 7 times (1 for each crime category) into work.use*/
   /*NOTE: Since the definition of the instruments depends on whether
           you are using Levitts measure of mayoral elections or my own, step2
           takes an argument of #lev# of #mcc#.  Therefore I wait until below to
           call step2. */
%include "~/j2/website/programs/table1.sas"; run; *waits for call to %analyze1();
%include "~/j2/website/programs/table2.sas"; run; *waits for call to %analyze2();
%include "~/j2/website/programs/checkcov.sas"; run; *waits for call to %chkcov();
%include "~/j2/website/programs/stockandyogo.sas"; run; *waits for call to %stckyogo();


/*TABLE 1, Column 1--standard deviations*/
  *unconditional and OLS s.d. taken from output for Column 4;
  *2SLS s.d. taken from output for Column 5;
  *look for "(conditional) standard deviation of crime categories" in log file;

         /*Column 2--OLS, wrong weights*/
  *Taken from AER, June 1997;

         /*Column 3--2SLS, wrong weights*/
  *Taken from AER, June 1997;

         /*Column 4--OLS, right weights*/
 /*NOTE: only the SECOND regression produces the weighted estimates*/
 /*NOTE: to get the standard error for the sum of the two lag
         coefficients, divide the sum of the coefficient estimates by
         the square root of the F-stat reported below the regression.*/
 /*NOTE: the p-value on the test of equality of the violent crime
         coefficients is the F-test with 3 numerator d.o.f., and the
         p-value on the test of equality of the property crime
         coefficients is the F-test with 2 numerator d.o.f.*/
  %step2(lev);
  %analyze1(holdwght,3,ols,0);
  %step2(lev); 
  %analyze1(holdwght,4,ols,0);

         /*Column 5--2SLS, right weights*/
  %let iset=z1-z28; /*elections uninteracted*/
  %step2(lev); *uses Levitt's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(lev);
  %analyze1(holdwght,2,2sls,&iset);

         /*Column 6--2SLS, right weights, my measure of mayoral elections*/
  %step2(mcc); *uses McCrary's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(mcc);
  %analyze1(holdwght,2,2sls,&iset);

/*TABLE 2, Column 1*/
  /*NOTE: To check that results are similar for obs with non-missing
          rape data, specify the final argument of analyze2 to be "2"
          (crime category # corresponding to rape).*/
  %analyze2(lev,1,1);

         /*Column 2*/
  %analyze2(lev,2,1);

         /*Column 3*/
  %analyze2(mcc,1,1);

         /*Column 4*/
  %analyze2(mcc,2,1);

/*TABLE 3, Column 1*/
   *published;

         /*Column 2*/
   *published;

         /*Column 3*/
   *published;

         /*Column 4--2SLS, city-size inter, Levitt*/
  %let iset=z29-z140; /*elections interacted with city-size dummies*/
  %step2(lev); *uses Levitt's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(lev);
  %analyze1(holdwght,2,2sls,&iset);

         /*Column 5--2SLS, region inter, Levitt*/
  %let iset=z141-z392; /*elections interacted with region dummies*/
  %step2(lev); *uses Levitt's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(lev);
  %analyze1(holdwght,2,2sls,&iset);

         /*Column 6--LIML, city-size inter, Levitt*/
  %let iset=z29-z140; /*elections interacted with city-size dummies*/
  %step2(lev); *uses Levitt's measure of mayoral elections;
  %analyze1(holdwght,1,liml,&iset);
  %step2(lev);
  %analyze1(holdwght,2,liml,&iset);

         /*Column 7--LIML, region inter, Levitt*/
  %let iset=z141-z392; /*elections interacted with region dummies*/
  %step2(lev); *uses Levitt's measure of mayoral elections;
  %analyze1(holdwght,1,liml,&iset);
  %step2(lev);
  %analyze1(holdwght,2,liml,&iset);

         /*Column 8--2SLS, city-size inter, McCrary*/
  %let iset=z29-z140; /*elections interacted with city-size dummies*/
  %step2(mcc); *uses McCrary's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(mcc);
  %analyze1(holdwght,2,2sls,&iset);

         /*Column 9--2SLS, region inter*/
  %let iset=z141-z392; /*elections interacted with region dummies*/
  %step2(mcc); *uses McCrary's measure of mayoral elections;
  %analyze1(holdwght,1,2sls,&iset);
  %step2(mcc);
  %analyze1(holdwght,2,2sls,&iset);

         /*Column 10--LIML, city-size inter*/
  %let iset=z29-z140; /*elections interacted with city-size dummies*/
  %step2(mcc); *uses McCrary's measure of mayoral elections;
  %analyze1(holdwght,1,liml,&iset);
  %step2(mcc);
  %analyze1(holdwght,2,liml,&iset);

         /*Column 11--LIML, region inter*/
  %let iset=z141-z392; /*elections interacted with region dummies*/
  %step2(mcc); *uses McCrary's measure of mayoral elections;
  %analyze1(holdwght,1,liml,&iset);
  %step2(mcc);
  %analyze1(holdwght,2,liml,&iset);


/*TABLE A.1--See crime2.  These calculations were done by hand by the
author in an excel spreadsheet.  Column 6 of Table A.1, in particular,
required simple judgement.*/

/*Finally, a footnote claimed that the unpooled estimates were not
very correlated.  This is true, but I verified it by printing out the
vcov for the estimates.  This takes up a _ton_ of space, so I am
including these results in a separate file.*/

  *%let iset=z1-z28; *elections uninteracted;
  *%step2(lev);
  *%chkcov(holdwght,1,2sls,&iset);

/*Finally finally, a different footnote noted that the Stock and Yogo
statistic was larger using my measure.*/
  %step2(lev);
  %stckyogo(1,lev);
   /*to actually compute it, go into GAUSS and call stockandyogo.prg*/

  %step2(mcc);
  %stckyogo(1,mcc);
   /*to actually compute it, go into GAUSS and call stockandyogo.prg*/









/*BELOW IS AN INITIAL VERSION OF THIS FILE, BUT ENTIRELY COMMENTED
OUT.  IF YOU HAVE SAS, YOU MAY UNCOMMENT THESE MACROS AS YOU SEE FIT,
AND VIEW THE RESULTS YOURSELF.  Alternatively, it should not be overly
difficult to conver the code to STATA or other software.  To make
things easier, I have provided the data set crime2 in Excel, STATA,
and SAS.  If you are unable to compute the LIML estimates using your
preferred estimates, not that the formulas given in Dufour and Jasiak
(forthcoming, International Economic Review) regarding computation of
the Anderson-Rubin confidence region give insight as to how to easily
compute the LIML estimator based on sums of squared residuals from
various regressions.  These regressions may be easily done in any
software package. */

/*Stuff for Table 1*/
  *1. OLS (in differences), published;

  *2. OLS (in differences), own calculations, but wrong weights;
*%step2(lev);
*%analyze1(holdstd,3,ols,0);

*%step2(lev);
*%analyze1(holdstd,4,ols,0);


  *3. OLS (in differences), own calculations, now using correct weights;
 /*NOTE: only the SECOND regression produces the weighted estimates*/
 /*NOTE: to get the standard error for the sum of the two lag
         coefficients, divide the sum of the coefficient estimates by
         the square root of the F-stat reported below the regression.*/
 /*NOTE: the p-value on the test of equality of the violent crime
         coefficients is the F-test with 3 numerator d.o.f., and the
         p-value on the test of equality of the property crime
         coefficients is the F-test with 2 numerator d.o.f.*/

*%step2(lev);
*%analyze1(holdwght,3,ols,0); 
*%step2(lev);
*%analyze1(holdwght,4,ols,0);


  *4. 2SLS, published so wrong weights;


  *5. 2SLS, own calculations, but wrong weights;
*%step2(lev);
*%analyze1(holdstd,1,2sls,&iset);
*%step2(lev);
*%analyze1(holdstd,2,2sls,&iset);


  *6. 2SLS, own calculations, now using correct weights;
*%step2(lev);
*%analyze1(holdwght,1,2sls,&iset);
*%step2(lev);
*%analyze1(holdwght,2,2sls,&iset);
*%step2(lev);
*%analyze1(holdwght,1,liml,&iset);
*%step2(lev);
*%analyze1(holdwght,2,liml,&iset);

  *7. All of the above use Levitt's measure of the mayoral electoral
  cycle. Here I want to try to use my own measure (which I believe has
  less measurement error) and see the effect on the 2SLS estimates;
*%step2(mcc);
*%analyze1(holdwght,1,2sls,&iset);
*%step2(mcc);
*%analyze1(holdwght,2,2sls,&iset);
*%step2(mcc);
*%analyze1(holdwght,1,liml,&iset);
*%step2(mcc);
*%analyze1(holdwght,2,liml,&iset);



/*Stuff for Table 2*/

  *1. Regression of once-lagged growth rate in cops on once- and
      twice-lagged mayoral, gubernatorial election year indicators;
  /*NOTE: To check the contention of the stub of Table 2 that results
          are similar for obs with non-missing rape data, specify the
          final argument of analyze2 to be "2" (crime category #
          corresponding to rape).*/

*%analyze2(lev,1,1);
*%analyze2(lev,2,1);
*%analyze2(mcc,1,1);
*%analyze2(mcc,2,1);

/*Finally, check correlation matrix for individual crime elasticities*/

*%step2(lev);
*%chkcov(holdwght,1,2sls,&iset);
*%step2(mcc);
*%chkcov(holdwght,1,2sls,&iset);

/*Finally finally, compute Stock and Yogo statistic*/
*%step2(lev);
*%step2(mcc);
*%stckyogo(1); /*to actually compute it, go into GAUSS and call stockandyogo.prg*/










