/*Here I want to see if I can get out the data needed to compute the
Stock and Yogo (mimeo, August 2001) test statistic G[T].  For
simplicity, I will assume that we are interested
in whether or not we should trust 2SLS estimates which do _not_ impose
cross-equation restrictions.  This leads to 2 endogenous regressors,
and 4 instruments (for the "uninteracted instruments" estimates).  As
well, this provides me with a check on the estimates that follow
Levitt's specification religiously.

What is needed:

1. Residuals from a regression of lagged police growth rates on 
   (i) the exogenous regressors
   (ii) the four election year indicators
  --> These residuals should be combined to form sigmaVV.  Put the
      residuals for the first lagged growth rate in one column, and
      "horizontally concatenate" the residuals for the second lagged
      growth rate, and call the matrix of NTx2 residuals E.
      sigmaVVhat is then just E'E/(NT-#exogreg-#inst).
2. Residuals from a regression of the four election year indicators on
   (i) the exogenous regressors
  --> call these residuals e1,e2,e3,e4.
3. Regress both lags of growth rates in police on e1-e4.
  --> call the _fitted_values_ from that regression f1, f2. "Horizontally
      concatenate" f1 and f2 into F.  Then F'F is the quadratic form
      in y perp with the projector onto the column space of Z perp in
      the middle of (2.6) in Stock and Yogo.

The output from this program should go into two raw files.  The first
should contain the residual matrix E.  The second should contain the
residual matrix F.

*/

%macro stckyogo(numnum,levmcc); /*choice of &numnum should be irrelevant*/
  %let wset=w1-w290 w333-w344;
  data stckyogo;
    set use(where=(number=&numnum));
    YY1=x1_&numnum;
    YY2=x2_&numnum;
    zz1=z&numnum; *first lag mayor;
    zz2=z%eval(&numnum+7); *second lag mayor;
    zz3=z%eval(&numnum+14); *first lag governor;
    zz4=z%eval(&numnum+21); *second lag governor;
  run;
  proc reg data=stckyogo;
    model zz1 zz2 zz3 zz4 = &wset;
      output out=EF1 R = zz1_w zz2_w zz3_w zz4_w;
  proc reg data=EF1;
    model YY1 YY2         = zz1 zz2 zz3 zz4 &wset;
      output out=EF2 R = e1 e2;
  proc reg data=EF2;
    model YY1 YY2         = zz1_w zz2_w zz3_w zz4_w;
      output out=EF3 P = f1 f2;
  run;
  data _null_;
    file "~/j2/website/programs/stockandyogo.raw.&levmcc" linesize=250;
    set EF3;
    put @1  e1
        @20 e2
        @40 f1
        @60 f2;
  run;
%mend;





